@@ -148,18 +148,18 @@ class LinuxlikeTests(BasePlatformTests):
         self.assertTrue(foo_dep.found())
         self.assertEqual(foo_dep.get_version(), '1.0')
         self.assertIn('-lfoo', foo_dep.get_link_args())
-        self.assertEqual(foo_dep.get_pkgconfig_variable('foo', {}), 'bar')
-        self.assertPathEqual(foo_dep.get_pkgconfig_variable('datadir', {}), '/usr/data')
+        self.assertEqual(foo_dep.get_pkgconfig_variable('foo', [], None), 'bar')
+        self.assertPathEqual(foo_dep.get_pkgconfig_variable('datadir', [], None), '/usr/data')
 
         libhello_nolib = PkgConfigDependency('libhello_nolib', env, kwargs)
         self.assertTrue(libhello_nolib.found())
         self.assertEqual(libhello_nolib.get_link_args(), [])
         self.assertEqual(libhello_nolib.get_compile_args(), [])
-        self.assertEqual(libhello_nolib.get_pkgconfig_variable('foo', {}), 'bar')
-        self.assertEqual(libhello_nolib.get_pkgconfig_variable('prefix', {}), self.prefix)
+        self.assertEqual(libhello_nolib.get_pkgconfig_variable('foo', [], None), 'bar')
+        self.assertEqual(libhello_nolib.get_pkgconfig_variable('prefix', [], None), self.prefix)
         if version_compare(libhello_nolib.check_pkgconfig(libhello_nolib.pkgbin),">=0.29.1"):
-            self.assertEqual(libhello_nolib.get_pkgconfig_variable('escaped_var', {}), r'hello\ world')
-        self.assertEqual(libhello_nolib.get_pkgconfig_variable('unescaped_var', {}), 'hello world')
+            self.assertEqual(libhello_nolib.get_pkgconfig_variable('escaped_var', [], None), r'hello\ world')
+        self.assertEqual(libhello_nolib.get_pkgconfig_variable('unescaped_var', [], None), 'hello world')
 
         cc = detect_c_compiler(env, MachineChoice.HOST)
         if cc.get_id() in {'gcc', 'clang'}:
@@ -373,8 +373,8 @@ class LinuxlikeTests(BasePlatformTests):
         Test that qt6 detection with qmake works. This can't be an ordinary
         test case because it involves setting the environment.
         '''
-        # Verify that qmake is for Qt5
-        if not shutil.which('qmake-qt6'):
+        # Verify that qmake is for Qt6
+        if not shutil.which('qmake6'):
             if not shutil.which('qmake'):
                 raise SkipTest('QMake not found')
             output = subprocess.getoutput('qmake --version')
@@ -1724,7 +1724,7 @@ class LinuxlikeTests(BasePlatformTests):
         p = subprocess.run([ar, 't', outlib],
                            stdout=subprocess.PIPE,
                            stderr=subprocess.DEVNULL,
-                           universal_newlines=True, timeout=1)
+                           text=True, timeout=1)
         obj_files = p.stdout.strip().split('\n')
         self.assertEqual(len(obj_files), 1)
         self.assertTrue(obj_files[0].endswith('-prelink.o'))
@@ -1760,3 +1760,23 @@ class LinuxlikeTests(BasePlatformTests):
 
         # If so, we can test that cmake works with "gcc -m32"
         self.do_one_test_with_nativefile('../cmake/1 basic', "['gcc', '-m32']")
+
+    @skipUnless(is_linux(), 'Test only applicable to Linux')
+    def test_install_strip(self):
+        testdir = os.path.join(self.unit_test_dir, '104 strip')
+        self.init(testdir)
+        self.build()
+
+        destdir = self.installdir + self.prefix
+        lib = os.path.join(destdir, self.libdir, 'liba.so')
+        install_cmd = self.meson_command + ['install', '--destdir', self.installdir]
+
+        # Check we have debug symbols by default
+        self._run(install_cmd, workdir=self.builddir)
+        stdout = self._run(['file', '-b', lib])
+        self.assertIn('not stripped', stdout)
+
+        # Check debug symbols got removed with --strip
+        self._run(install_cmd + ['--strip'], workdir=self.builddir)
+        stdout = self._run(['file', '-b', lib])
+        self.assertNotIn('not stripped', stdout)
